@@ -3,10 +3,9 @@
 # SPDX-License-Identifier: MIT
 import time
 import board
-import busio
 from adafruit_emc2101.emc2101_lut import EMC2101_LUT as EMC2101
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()  # uses board.SCL and board.SDA
 
 FAN_MAX_RPM = 1700
 emc = EMC2101(i2c)
